# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog],
and this project adheres to [Semantic Versioning].

## [Unreleased]

## [0.4.2] - 2024-03-19

- Test github ci

## [0.4.1] - 2024-03-19

- Test release takeoff-config for cross-platform distribution. 

## [0.4.0] - 2024-03-08

- First versioned release of takeoff-config, with a new release process that pushes takeoff-config to pypi alongside takeoff-client with the same version [PR 1079](https://github.com/TNBase/pantheon/pull/1079)